@@ -1,4 +1,30 @@
-# This function returns the solution of the minimization problem
+#' zsumlpmin at orloca package
+#'
+#' This function returns the solution of the minimization problem.
+#'
+#' \code{zsummin} function with \eqn{l_p} norm. Mainly for internal use.
+#'
+#' @details
+#' If \eqn{p<1} then \eqn{l_p} is not a norm, so only \eqn{p>=1} are valid values.
+#'
+#' Since \eqn{l_2} norm is the Euclidean norm, when \eqn{p=2} \code{zsumlpmin} are equal to \code{zsummin}.
+#' But the computations involved are greater for the first form.
+#' 
+#' @name zsumlpmin
+#' @aliases zsumlpmin zsumlpmin,loca.p-method
+#' @keywords internal classes optimize
+#' @param o An object of loca.p class.
+#' @param x The x coordinate of the starting point.
+#' @param y The y coordinate of the starting point.
+#' @param p p value for \eqn{l_p} norm.
+#' @param max.iter Maximum number of iterations allowed.
+#' @param eps The module of the gradient in the stop rule.
+#' @param verbose If TRUE, then the function produces detailed output.
+#' @param algorithm The method to be use. For this version of the package, the valid values are: "gradient" or "g" for a gradient based method, "search" or "s" for local search method (this option is deprecated), "ucminf" or "u" for optimization with ucminf from ucminf package, and "weiszfeld" or "w" for the weiszfeld method or any of the valid method for optim function, now "Nelder-Mead", "BFGS", "CG", "L-BFGS-B", "SANN". "weiszfeld" is the default value.
+#' @param \ldots Other options for optimization algorithms.
+#' @return \code{zsumlpmin} returns an array with the coordinates of the solution point.
+#' @seealso See also \code{\link{zsummin}}, \code{\link{orloca-package}}, \code{\link{loca.p}} and \code{\link{zsum}}.
+#' 
 setGeneric("zsumlpmin",
            function (o, x=0, y=0, p=2, max.iter=100, eps=1.e-3, verbose=FALSE, algorithm="weiszfeld", ...) standardGeneric("zsumlpmin")
 )
@@ -6,7 +32,6 @@ setGeneric("zsumlpmin",
 # Optimization by ucminf function from ucminf package
 zsumlpminucminf.loca.p <- function (o, x=0, y=0, p=2, max.iter=100, eps=1.e-3, verbose=FALSE)
    {
-     require('ucminf')
      zzsum <- function(xx) zsumlp(o, xx[1], xx[2], p=p)
      sol <- ucminf(par = c(x, y), fn = zzsum, control=list(maxeval=max.iter, trace=verbose))
      if (verbose) cat(gettext(sol$message));
@@ -14,6 +39,7 @@ zsumlpminucminf.loca.p <- function (o, x=0, y=0, p=2, max.iter=100, eps=1.e-3, v
    }
 
 # Gradient Method
+#' @export
 setMethod("zsumlpmin", "loca.p",
 function (o, x=0, y=0, p=2, max.iter=100, eps=1.e-3, verbose=FALSE, algorithm="weiszfeld", ...)
    {
