@@ -1,6 +1,5 @@
 # Loading required graphics packages
-require(grDevices)
-require(graphics)
+opar <- par(ask = dev.interactive(orNone = TRUE))
 
 # Creation of new loca.p object
 o <- loca.p(x = c(-1, 1, 0), y = c(0, 0, 1))
@@ -27,12 +26,10 @@ persp(o, col=cm.colors(10000), border=FALSE, shade=TRUE, theta=50, phi=5, ltheta
 persp(o, col=cm.colors(10000), border=FALSE, shade=TRUE, theta=50, phi=5, ltheta=135, lphi=90)
 
 # Plots with a background image
-if (require('png')) {  
-  file = system.file('img', 'spain_provinces.png', package='orloca')
-  img = readPNG(file)
-  plot(loca.p(x=.55, y=.62), img=img,  xlim=c(0,1), ylim=c(0,1), xleft=0, ybottom=0, xright=1, ytop=1)
-  contour(loca.p(x=.55, y=.62), img=img,  xmin=0, ymin=0, xmax=1, ymax=1, xleft=0, ybottom=0, xright=1, ytop=1)
-}
+file = system.file('img', 'spain_provinces.png', package='orloca')
+img = readPNG(file)
+plot(loca.p(x=.55, y=.62), img=img,  xlim=c(0,1), ylim=c(0,1), xleft=0, ybottom=0, xright=1, ytop=1)
+contour(loca.p(x=.55, y=.62), img=img,  xmin=0, ymin=0, xmax=1, ymax=1, xleft=0, ybottom=0, xright=1, ytop=1)
 
 # Find the minimum
 zsummin(o)
@@ -51,3 +48,6 @@ zsum(p, sol[1], sol[2])
 
 # Timing the algorithm
 system.time(zsummin(p))
+
+# Restoring graphical parameters
+par(opar)
